{% extends "blocks/unical_menu_grey_box_generic.html" %}

{% load static %}

{% block icon %}
<div class="col-2">
    <b>
        <svg class="icon">
            <use xlink:href="{% static 'svg/sprite.svg' %}#it-arrow-right-circle"></use>
        </svg>
    </b>
</div>
{% endblock %}

