{% load static %}

{% load unicms_contexts %}


<div class="row">
    <div class="col">
        <div class="card-wrapper card-space">
            <div class="card card-bg no-after">
                <div class="card-body">
                    <div class="etichetta">
                        {% for cat in publication.categories %}
                        <span class="badge badge-pill badge-grey-unical my-1 py-2 px-4 mr-1">
                            <a class="no-color" href="{% call obj=publication method='get_url_list' category_name=cat %}">
                                <b>{{ cat }}</b>
                            </a>
                        </span>
                        {% endfor %}
                    </div>

                    {% call obj=publication method='url' webpath=webpath as url %}
                    <h4 class="card-title">
                        {% if url %}
                        <a href="{{ url }}" class="no-color">
                        {% endif %}
                            {{ publication.title }}
                        {% if url %}
                        </a>
                        {% endif %}
                    </h4>
                    <a href="#">
                        <svg class="icon">
                            <use xlink:href="{% static 'svg/sprite.svg' %}#it-share"></use>
                        </svg>
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>

