{% extends "department.html" %}

{% load i18n %}
{% load static %}

<!-- load custom template tags -->
{% load unicms_carousels %}
{% load unicms_contexts %}
{% load unicms_menus %}
{% load unicms_templates %}
{% load unicms_pages %}
{% load unicms_publications %}


<!-- Logo in Header -->
{% block header_center_logo_side %}
<image src="{% static 'images/logos/dfssn.svg' %}" class="h-100" />
{% endblock header_center_logo_side %}

{% block header_slim_mobile_org_name_side %}
<image src="{% static 'images/logos/dfssn.svg' %}" class="mw-100" />
{% endblock header_slim_mobile_org_name_side %}
