{% extends 'bases/error-page.html' %}

{% load i18n %}

{% block error_type %}
    {% trans "Error 404" %}
{% endblock error_type %}

{% block error_description %}
    {% trans "Page or Resource not found 404" %}
{% endblock error_description %}
